@@ -1,8 +1,5 @@
 from django.contrib.auth.tokens import default_token_generator
 from django.contrib.sites.models import Site
-from django.core.management.color import no_style
-from django.db import connection
-from django.db.models.base import ModelBase
 from django.db.utils import IntegrityError
 from django.test import TestCase
 from django.utils import timezone
@@ -13,38 +10,6 @@ from mock import patch
 
 from . import models
 from .factories import UserFactory
-from .. import mixins
-
-
-class AbstractModelMixin(object):
-    """
-    Mixin class for tests of (abstract) model mixins. To use, subclass and specify
-    the mixin class variable. A model using the mixin will be made available in self.model.
-
-    From http://michael.mior.ca/2012/01/14/blog/unit-testing-django-model-mixins.html
-    """
-    def setUp(self):
-        # Create a dummy model which extends the mixin
-        self._model_name = '__TestModel__' + self.mixin.__name__
-        self.model = ModelBase(
-            self._model_name,
-            (self.mixin,),
-            {'__module__': self.mixin.__module__},
-        )
-
-        # Create the schema for our test model
-        self._style = no_style()
-        sql, _ = connection.creation.sql_create_model(self.model, self._style)
-
-        self._cursor = connection.cursor()
-        for statement in sql:
-            self._cursor.execute(statement)
-
-    def tearDown(self):
-        # Delete the schema for the test model
-        sql = connection.creation.sql_destroy_model(self.model, (), self._style)
-        for statement in sql:
-            self._cursor.execute(statement)
 
 
 class TestUser(TestCase):
@@ -175,8 +140,8 @@ class TestUserManager(TestCase):
         self.assertTrue(user.is_superuser)
 
 
-class TestVerifyEmailMixin(AbstractModelMixin, TestCase):
-    mixin = mixins.VerifyEmailMixin
+class TestVerifyEmailMixin(TestCase):
+    model = models.VerifyEmailUser
 
     def test_save(self):
         user = self.model()
